@@ -4,7 +4,8 @@ from .deployment import deployment
 from .tokens import token_util
 from .simple_jwt import simple_jwt
 from importlib_metadata import version
+from .email import email
 
-__all__ = ["resources", "custom_server", "deployment", "token_util", "simple_jwt"]
+__all__ = ["resources", "custom_server", "deployment", "token_util", "simple_jwt", "email"]
 
 __version__ = version("willing_zg")
